"""
    This module shows how to take sampled audio data from LabVIEW, and turn
    it into a text transcription by calling a cloud service.
    
    Before using this module, you will need to install a Python package
    called "speech_recognition".  Many Python packages are available through
    the Canopy Package Manager, but there are thousands of additional
    open-source packages available from the Python Package Index.  They
    can be easily installed using the "pip" command-line tool.
    
    Here's how:
    
    1. Open a terminal.  If you are using Enthought Canopy, go to the
       Start menu, select "Enthought Canopy", and then "Canopy Command Prompt".
    2. Run the command "pip install SpeechRecognition".

    The function "recognize" below uses the Google cloud transcription service.
    You can also use Bing or other services; this guide describes how:
    
    https://pypi.python.org/pypi/SpeechRecognition/
"""
   
import speech_recognition as sr

def recognize(float_data):
    """ Take a 1D array of data from the microphone, and return text.
    """
    
    # Put the data into the format expected by the speech_recognition package
    data = float_data*(2**13)
    data = data.astype('i2')
    audio = sr.AudioData(data.tostring(), 22050, 2)
    
    # Call the cloud service
    r = sr.Recognizer()
    try:
        # To use Bing or other services, replace this line.
        text = r.recognize_google(audio)
        return text.capitalize()
    except sr.UnknownValueError:
        return "Sorry, I didn't get that."

